# Data description for essd-2020-106

**An integrated observation dataset of the hydrological-thermal deformation in the permafrost slopes and engineering infrastructure in the Qinghai-Tibet Engineering Corridor**

----
## Description
- [ ]  **Meteorological observations** 
Observation of meteorological factors was conducted at two permanent meteorological stations (Golmud and Wudaoliang) and one field meteorological station (Xidatan) with daily meteorological records. All three meteorological stations contain ground observations.

- [ ]  **Ground observations** 
The ground temperature and moisture data from the near-surface to within 270 cm in the active layer were recorded. In situ ground observations were deployed starting in July 2013 using thermocouple probes (105T, Campbell Scientific) to measure the soil temperature and using 11 time-domain reflectometer (TDR) probes (model CS615-L, Campbell Scientific) to measure the soil volumetric water content.

- [ ]  **TLS measurements** 
A FARO Focus3D X130 3D laser scanner and six Trimble 5700 GNSS systems were deployed around permafrost slopes between May 2014 and October 2015. As a supplement to the TLS point cloud data, we used Interferometric Synthetic Aperture Radar (InSAR) technology to prepare Sentinel-1 deformation data for the study area from 2014 to 2020.

- [ ]  **UAV RGB and TIR images** 
Two permafrost slopes were conducted four flight experiments with UAV-mounted RGB and TIR sensors in 2016 and 2017.

- [ ]  **R code of permafrost indices and visualization** 
R Script for plotting meteorological observation data and permafrost indices (MAAT and MAGST) during 1955-2020.

----
## Keywords
-- **Theme:** Permafrost slope; Permafrost engineering; Freeze-thaw; hydrological-thermal-Deformation; Qinghai-Tibet plateau
-- **Discipline:** cryosphere; In-situ monitoring data; Remote sensing data using TLS and UAV
-- **Places:** Qinghai-Tibet Engineering Corridor; Kunlun Mountain Pass close to Hoh Xil Nature Reserve

----
## Data details
-- **Scale:** UAV RGB: ~5 cm; UAV TIR: ~ 20 cm;  TLS measurements: 0.009°
-- **Coordinate Reference System:** EPSG: 4326 - WGS 84 
-- **Filesize:**~ 13 G
-- **Data format:** GeoTiff, CSV, EXCEL XLSX, TXT, WRP, Tif, JPG

----
## Space scope
                       North：35°39′10″
           West：90°3′30″	-	East：90°3′55″
	                   South：35°38′35″

<iframe src="https://www.google.com/maps/embed?pb=!1m14!1m12!1m3!1d7502.059424775693!2d94.06124601719918!3d35.651680460389!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!5e1!3m2!1sen!2s!4v1615280891382!5m2!1sen!2s" width="950" height="450" style="border:0;" allowfullscreen="" loading="lazy"></iframe>

----
## Time period


> **Table 1.** Observations period of all datasets.


>
| Data Type                                      | Location           | Period                 | Remark                                           |
| ---------------------------------------------- | ------------------ | ---------------------- | ------------------------------------------------ |
| Meteorological observations                    | Golmud station     | 1955-2020              | National Reference Station                       |
| Meteorological observations                    | Xidatan station    | 2014-2018              | National General Station                         |
| Meteorological observations                    | Wudaoliang station | 1956-2020              | National Reference Station                       |
| Ground observations                            | Study Area         | 2014-2019              | Field test site                                  |
| Ground observations                            | Golmud station     | 1955-2020              | National Reference Station                       |
| Ground observations                            | Xidatan station    | 2014-2018              | National General Station                         |
| Ground observations                            | Wudaoliang station | 1956-2020              | National Reference Station                       |
| TLS measurements                               | Study Area         | 2014-2015              |Contains measurement and comparative analysis data|
| InSAR                                          | Study Area         | 2014-2020              |Contains thawing and freezing period data         |
| UAV RGB and TIR images                         | Study Area         | 2016-2017              | tif & jpg can be processed by Pix4Dmapper & FLIR |
| R code of permafrost indices and visualization | Stations           | 1955-2020              | Plot Fig. 2 & H1; Computing MAAT & MAGST         |


## Meteorological and Ground observations

> **Table 2.** Observations period of datasets. 

>
| Data Type                    | Location          | Period    | File Names                               |
| ---------------------------- | ----------------- | --------- | ---------------------------------------- |
| Meteorological observations  | Golmud station    | 1955-2020 | Meteo_52818_Golmud_1955-2020.csv         |
| Meteorological observations  | Xidatan station   | 2014-2018 | Meteo_XDTMS_Xidatan_2014-2018.csv        |
| Meteorological observations  | Wudaoliang station| 1956-2020 | Meteo_52908_Wudaoliang_1956_2020.csv     |
| Ground observations          | Study Area        | 2014-2019 | GT_00000_Slopes_2014-2019.csv            |
| Ground observations          | Golmud station    | 1955-2020 | GT_52818_Golmud_1955-2020.csv            |
| Ground observations          | Wudaoliang station| 1956-2020 | GT_52908_Wudaoliang_1956-2020.csv        |


> **Table 3.** Ground data Metadata of meteorological stations data. The file name with **'GT'** is ground observation data. Field Name is a data variable customized by the China Meteorological Administration.

>
| ID | Variable                                 | Type      | Field Name | Unit  | Description |
| -- | ---------------------------------------- | --------- | ---------- | ----- | ----------- |
| 1  | Station ID                               | Number(5) | V01000     |       |             |
| 5  | Year                                     | Number(4) | V04001     | Year  |             |
| 6  | Month                                    | Number(2) | V04002     | Month |             |
| 7  | Day                                      | Number(2) | V04003     | Day   |             |
| 32 | Evaporation                              | Number(6) | V13241     | mm    | evaporation |
| 53 | average ground temperature at 0 cm       | Number(6) | V12240     | ℃    | GT_0_AVG    |
| 54 | daily maximum ground temperature at 0 cm | Number(6) | V12213     | ℃    | GT_0_MAX    |
| 56 | daily minimum ground temperature at 0 cm | Number(6) | V12214     | ℃    | GT_0_MIN    |
| 58 | average ground temperature at 5 cm       | Number(6) | V12240_005 | ℃    | GT_5_AVG    |
| 59 | average ground temperature at 10 cm      | Number(6) | V12240_010 | ℃    | GT_10_AVG   |
| 60 | average ground temperature at 15 cm      | Number(6) | V12240_015 | ℃    | GT_15_AVG   |
| 61 | average ground temperature at 20 cm      | Number(6) | V12240_020 | ℃    | GT_20_AVG   |
| 62 | average ground temperature at 40 cm      | Number(6) | V12240_040 | ℃    | GT_40_AVG   |
| 63 | average ground temperature at 50 cm      | Number(6) | V12240_050 | ℃    | GT_50_AVG   |
| 64 | average ground temperature at 80 cm      | Number(6) | V12240_080 | ℃    | GT_80_AVG   |
| 65 | average ground temperature at 160 cm     | Number(6) | V12240_160 | ℃    | GT_160_AVG  |
| 66 | average ground temperature at 320 cm     | Number(6) | V12240_320 | ℃    | GT_320_AVG  |
 

   
> **Table 4.** Meteorological Metadata of meteorological stations data. The file name with **'Meteo'** is Meteorological observation data. The suffixes _MIN, _MAX, _AVG, and _QC indicate the minimum, maximum, and average values and quality control code of the variable, respectively, while 32766, NA, and NAN indicate null values. The suffix of TotalPrecip with “20_8”, “8_20”, and “20_20” are the total precipitation from 20 to 8 o'clock the next day, 8 to 20 o'clock, and 20 to 20 o'clock the next day, respectively. The suffixes of Evaporation with “SmallEvaporators” and “LargeEvaporators” are the data monitored by the small and large evaporator respectively. The suffix of GT with a number indicates the ground temperature in centimeters.

> 
| Variable Name              | Description                            | Unit          |
| -------------------------- | -------------------------------------- | ------------- |
| Temperature                | Air temperature                        | °C            |
| Wind                       | Wind speed                             | m/s           |
| WindDirection              | Wind direction                         | 16 directions |
| Extreme_Wind               | Extreme wind speed                     | m/s           |
| WindDirection_Extreme_Wind | Wind direction with extreme wind speed | 16 directions |
| TotalPrecip                | Precipitation                          | mm            |
| Corrected_P                | Corrected precipitation                | mm            |
| Evaporation                | Evaporation                            | mm            |
| Humidity                   | Air humidity                           | %             |
| Press                      | Atmospheric pressure                   | hPa           |
| Sunshine                   | Sunshine duration                      | h             |
| GT                         | Ground temperature                     | °C            |


> **Table 5.** Metadata of Xidatan field station. Underlay type: Alpine meadow.
 
>
| Observations    | Probe Model | Erection Height | Variable Name | Unit   |
| --------------- | ----------- | --------------- | ------------- | ------ |
| Air temperature | HMP45C      | 2m              | Ta_2m         | °C     |
| Air humidity    | HMP45C      | 2m              | RH_2m         | %      |
| Precipitation   | T-200B      | 1.5m            | Precipitation | mm     |
| Wind speed      | 05103_L/RM  | 2m              | WS_2m         | m/s    |
| Total radiation | CM3         | 2m              | DSR           | w/㎡   |

> **Table 6.** Metadata of ground data of Slope. Underlay type: Bare land. The suffixes "_" , number and "cm"  indicate the underground observe depth of the variable.

>
| Observations       | Probe Model | Variable Name | Unit |
| ------------------ | ----------- | ------------- | ---- |
| Ground Temperature | 105T        | Soil_Temp     | °C   |
| Ground Moisture    | CS615-L     | Soil_Water    | %    |

## TLS measurements

- [ ] **TLS measurements** 
There are a total of 4 monitorings between May 2014 and October 2015 within two thawing periods and a freezing period. The three freeze-thaw phases are referred to as "first thawing" (May 2014 to October 2014, called here "period 2-1"), "first freezing" (October 2014 to May 2015, called here "period 3-2"), "second thawing" (May 2015 to October 2015, called here "period 4-3"), "one thawing and one freezing stage" (May 2014 to May 2015, called here "period 3-1"), and "two thawing and one freezing stage" (May 2014 to October 2015, called here "period 4-1") in the following. The file directories for each monitoring are: first, second, third, and fourth. And the file also contains comparative analysis data of different periods.

> **Table 7** Freeze-thaw stages of TLS scanner data. The folder name is from number to number, such as "3-1", which represents the fusion data of the first and third monitoring. The suffix of TLS measurement data is wrp. The folder name is a or b, representing permafrost slope A or B.

> 
| Status     | Condition                    | Date Span             | Days | Slope   | Data points |
| ---------- | ---------------------------- | --------------------- | ---- | ------- | ----------- |
| Period 2-1 | Thawing                      | 05/02/2014–10/10/2014 | 161  | Slope A | 1251706     |
| Period 2-1 | Thawing                      | 05/02/2014–10/10/2014 | 161  | Slope B | 1367438     |
| Period 3-2 | Freezing                     | 10/10/2014–05/03/2015 | 205  | Slope A | 1291356     |
| Period 3-2 | Freezing                     | 10/10/2014–05/03/2015 | 205  | Slope B | 1366141     |
| Period 4-3 | Thawing                      | 05/03/2015–10/04/2015 | 154  | Slope A | 1248325     |
| Period 4-3 | Thawing                      | 05/03/2015–10/04/2015 | 154  | Slope B | 1382768     |
| Period 3-1 | one thawing and one freezing | 05/02/2014–05/03/2015 | 366  | Slope A | 1278448     |
| Period 3-1 | one thawing and one freezing | 05/02/2014–05/03/2015 | 366  | Slope B | 1279204     |
| Period 4-1 | two thawing and one freezing | 05/02/2014–10/04/2015 | 520  | Slope A | 1279706     |
| Period 4-1 | two thawing and one freezing | 05/02/2014–10/04/2015 | 520  | Slope B | 1207493     |

----

- [ ] **InSAR data** 
The Sentinel-1 mission provides data from a dual-polarization C-band Synthetic Aperture Radar (SAR) instrument. This collection includes the S1 Ground Range Detected (GRD) scenes, processed using the Sentinel-1 Toolbox to generate a calibrated, ortho-corrected product. File directory is InSAR.

> **Table 8.** InSAR data for Permafrost slope A & B, including the study area vector shapefile file(SlopeAB). Direction of the orbit ('ASCENDING' or 'DESCENDING') for the oldest image data in the product (the start of the product). The spatial resolution is 10 meters.

>
| Data Type       | Period      | Condition            | Remark             |
| ----------------| ------------| -------------------- |--------------------|
| asc             | 2014-2016   |  Tawing              |   ASCENDING        |
| asc             | 2014-2017   |  Freezing            |   ASCENDING        |
| asc             | 2017-2019   |  Tawing              |   ASCENDING        |
| asc             | 2017-2020   |  Freezing            |   ASCENDING        |
| desc            | 2014-2016   |  Tawing              |   DESCENDING       |
| desc            | 2014-2017   |  Freezing            |   DESCENDING       |
| desc            | 2017-2019   |  Tawing              |   DESCENDING       |
| desc            | 2017-2020   |  Freezing            |   DESCENDING       |
| Study Area boundary|          |                      |   SlopeAB:Shapefile|

- [ ] **Photogrammetry data**
In addition, during the first TLS experiment, we also used a Nikon D-series digital camera to take pictures of slope A without interruption while moving in a straight line along the Qinghai-Tibet Highway. The finally generated point cloud data was also placed in the data set, and the file name was **"Photogrammetry dense point cloud.txt".**

## UAV RGB and TIR images

> For these two slopes, we conducted four flight experiments with UAV-mounted RGB and TIR sensors. The directory of flight images for RGB and thermal infrared sensors is RGB and TIR. The TIR data formats selected for 2016 and 2017 were TIF and JPG, respectively.

> There are three directories under the RGB directory: **20160417, 20160830 and 20170822**, the format is yyyyymmdd, which represent the UAV photos taken by the RGB camera that day. Please use **exiftool** to view the metadata information of pictures such as timestamp and location.

> There are three directories under the TIR directory: **20160830, 20170722 and 20170823**, the format is yyyyySlope, which represent UAV photos taken by the TIR sensor of the year. Please use exiftool to view the metadata information of pictures such as timestamp, location, and center point temperature.

> To obtain temperatures, a sensor that is able to provide absolute temperature is needed (instead of relative temperature). The FLIR Vue Pro and the Zenmuse XT do not provide absolute temperature. However, the FLIR Vue Pro and the Zenmuse XT both have a radiometric version that does record absolute temperature. It is recommended to do the processing with the uncompressed Tiff images and create the following index to view absolute temperature.
```
0.04*thermal_ir - 273.15
```

- This also applies (with the same formula) to the newer Wiris camera.

- The Thermomap camera from senseFly also records absolute temperature. The corresponding index is
```
0.01*thermal_ir - 100
```

- This index is already present in the software and is loaded automatically for Thermomap projects.

> **How to get the coefficient of Tiff format? or is the coefficient variable?** 

> A **new method** to build the function.

- **1.** Use exiftool software (Ubuntu) to get the meta of TIFF or JPG data.
```sh
exiftool DJI_0777.tif
```

- **2.**  Find "Central Temperature".
```sh
exiftool DJI_0777.tif|grep "Central Temperature"
```

- **3.** Get the Min/Max Digital Values of TIFF or JPG data from ARCGIS or QGIS.

- **4.** Central temperature is the min temperature in my data through the analysis of FLIR Tools, PLEASE NOTICE, this may be different.

- **5.** Build a linear equation between Digital Values and Central Temperature.

- **6.** Get temperature from TIFF or JPG format data through the equation.

- **7.** And then, we can do anything, such as simple operation and modeling using Matlab, R, Python and so on.

![linear equation](https://www.researchgate.net/profile/Lihui-Luo/post/FLIR-Vue-Pro-How-do-we-extract-temperature-from-TIFF-16-bit-data-raw-data/attachment/59d6596279197b80779aee7b/AS%3A542300975910912%401506306036164/image/DN_GT.tiff)
> **Figure 1.** The linear equation between Digital Values and Central Temperature.

> **Table 9.** UAV flight time during the 2016–2017.

> 
| Flight Date | Flight Time | Height | Slope          | Sensor |
| ----------- | ----------- | ------ | -------------- | ------ |
| yyyymmdd    | hh:mm       | m      |                |        |
| 20160417    | 13:36-13:56 | 20-120 | Slopes A and B | RGB    |
| 20160830    | 10:18-13:55 | 120    | Slopes A and B | RGB    |
| 20170822    | 11:26-13:46 | 120    | Slopes A and B | RGB    |
| 20160830    | 12:47-12:52 | 30     | Slope A        | TIR    |
| 20170722    | 11:00-15:51 | 150    | Slopes A and B | TIR    |
| 20170823    | 10:30-17:25 | 150    | Slopes A and B | TIR    |

----

> **Table 10.** Processed UAV data.

>
| Data Type                     |  file name                    |
| ------------------------------| ------------------------------|
| Boundary                      |SlopeAB:Shapefile              |
| Digital Surface Model(DSM)    |DSM_SlopeAB:Raster             |
| Mosaic                        |Mosaic_SlopeAB:Raster          |
| Classification of frozen soil |QTP_FrozenSoil_Class:Shapefile |

## R code of permafrost indices and visualization
### Script

- [ ] **MAAT.R**
>- Function for computing Mean Annual Air Temperature (MAAT) index

- [ ] **MAGST.R**
>- Function for computing Mean Annual Ground Surface Temperature (MAGST) index

- [ ] **Meteorogical.R**
>- Plot Meteorogical station observation data, MAAT and MAGST indices

----

### Data

>  The **Data directory** "./Data" contains the following data:

> **Table 11.** Data files for computing and drawing. Other files in the data directory are calculated files and can be deleted.

|     Data file                                           |     Description                                                                                                                             | Figure  |  
|---------------------------------------------------------|---------------------------------------------------------------------------------------------------------------------------------------------|---------|
| Meteo_52818_Golmud_1955-2020.csv                        | Meteorological observations of Golmud field station                                                                                         |  H1     |
| Meteo_52908_Wudaoliang_1956_2020.csv                    | Meteorological observations of Wudaoliang field station                                                                                     |  H1     |
| XDTMS2014-2018.csv                                      | Meteorological observations of Xidatan field station                                                                                        |         |
| XDTMS2014-2018_GT.csv                                   | Xidatan field station, ONLY Ground Temperature in different depth                                                                           |  2      |
| XDTMS2014-2018_PREC.csv                                 | Xidatan field station, ONLY Precipitation                                                                                                   |  2      |
| MAAT_MAGST_Golmud_Wudaoliang_1956-2020.csv              | After running MAAT and MAGST, the data of the two field stations need to be merged together for drawing. This data has been manually merged |  H1     |

> The **output data** is also placed in this directory "./Data".

----

### Figure

> The output Figures are placed in Figure directory './Figure', and the **operation video** are also placed in this directory.


----

### Usage


> **Please execute the following statement in Rstudio or R software.** 

>  First, please install **ggplot2** package in Rstudio or R software, and set the environment variables.
> 
```r
install.packages('ggplot2')
library('ggplot2')
# Init
# clear the environment
rm(list=ls())
# set workdir
# setwd('./Script')
# Data directory
DataRoot  <- './Data'
# Figure directory
FigRoot  <- './Figure'
```

> and then run Meteorological.R.

```r
source('Meteorological.R')
```

> Or copy the code in Meteorological.R **in turn** and execute it in Rstudio or R software.

> MAAT.R and MAGST.R have been implemented in Meteorological.R, **no additional execution is required.**

> 
```r
source('MAAT.R')
source('MAGST.R')
```

----
### Operation video
![Operation GIF](https://github.com/iffylaw/ESSD-2020-106/blob/main/ScriptRstudio.gif?raw=true)

----
### Requirements

>- RStudio Version 1.3.959 or later
>- R Statistical Computing Software, 4.0.2 or later
>- Package ggplot2 version 3.3.2

----
## Article DOI 
>- https://doi.org/10.5194/essd-2020-106
>- This article contains all the data DOI.

## Citation
>  Luo, L., Zhuang, Y., Zhang, M., Zhang, Z., Ma, W., Zhao, W., Zhao, L., Wang, L., Shi, Y., Zhang, Z., Duan, Q., Tian, D., and Zhou, Q.: An integrated observation dataset of the hydrological-thermal-deformation dynamics in the permafrost slopes and engineering infrastructure in the Qinghai-Tibet Engineering Corridor, Earth Syst. Sci. Data Discuss. [preprint], https://doi.org/10.5194/essd-2020-106, in review, 2020.

----
## Abbreviation

> **Table 12.** Some abbreviations

| Abbreviation | Full name                                  |
| ------------ | ------------------------------------------ |
| CGCS         | China Geodetic Coordinate System           |
| DSM          | Digital surface model                      |
| GNSS         | Global navigation satellite system         |
| InSAR        | Interferometric Synthetic Aperture Radar   |
| KMP          | Kunlun Mountain Pass                       |
| MAAT         | Mean annual air temperature                |
| MAGST        | Mean annual ground surface temperature     |
| MAGT         | Mean annual ground temperature             |
| NGCN         | National Geodetic Control Network          |
| NMIC         | National Meteorological Information Center |
| QTEC         | Qinghai-Tibet Engineering Corridor         |
| QTH          | Qinghai-Tibet Highway                      |


----
## Data resource provider

> **Lihui Luo**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<luolh@lzb.ac.cn>

> **Yanli Zhuang**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<zhuangyl@lzb.ac.cn>

> **Mingyi Zhang**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<myzhang@lzb.ac.cn>

> **Zhongqiong Zhang**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<zhangzq@lzb.ac.cn>

> **Wei Ma**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<mawei@lzb.ac.cn>
 
> **Wenzhi Zhao** 
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<zhaowzh@lzb.ac.cn>

> **Lin Zhao**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<linzhao@lzb.ac.cn>

> **Li Wang**
Qinghai Institute of Meteorological Science
<liw0209@sohu.com>

> **Yanmei Shi**
32016 PLA Troops

> **Ze Zhang**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<zhangze@lzb.ac.cn>

> **Quntao Duan**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<duanqt@lzb.ac.cn>
 
> **Deyu Tian**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<tiandy@lzb.ac.cn>

> **Qingguo Zhou**
Lanzhou University
<zhouqg@lzu.edu.cn>

----
## Acknowledgements

> Funded by the National Natural Science Foundation of China (41871065), the National Science Fund for Distinguished Young Scholars (41825015), the Key Research Project of Frontier Science of Chinese Academy of Sciences (QYZDJ-SSW-DQC040), and the Strategic Priority Research Program of the Chinese Academy of Sciences (XDA19090122).

----
## License

> Apache License 2.0

----
## Contact

> **Dr. Lihui Luo**
Northwest Institute of Eco-Environment and Resources, Chinese Academy of Sciences
<luolh@lzb.ac.cn>

![LOGO](https://github.com/iffylaw/ESSD-2020-106/blob/main/DSSLOGO.png?raw=true)

----
updated: 2021/06/22